@@ -12,7 +12,7 @@ GetOptions(
    'i|interval=i'   => \(my $INTERVAL = 10),
    'p|print-config' => \my $PRINT_CONFIG,
 
-   'adapter|A=s' => \( my $ADAPTER = "BusPirate" ),
+   'adapter|A=s' => \my $ADAPTER,
 ) or exit 1;
 
 my $chip = Device::Chip::HTU21D->new;
@@ -33,9 +33,6 @@ if( $PRINT_CONFIG ) {
    printf "%20s: %s\n", $_, $config->{$_} for sort keys %$config;
 }
 
-my $gain = 1;
-my $smallcount;
-
 while(1) {
    my $temp = $chip->read_temperature->get;
    printf "Temperature: %.2fC\n", $temp;
